@@ -720,44 +720,6 @@ static BOOL printConfig(LPAPXCMDLINE lpCmdline)
     return TRUE;
 }
 
-/* Common error reporting */
-static void logGrantFileAccessFail(LPCWSTR szUser, LPCWSTR szPath, DWORD dwError)
-{
-    int     len = 0;
-    CHAR    errmsg[SIZ_HUGLEN];
-    WCHAR sPath[SIZ_PATHLEN];
-
-    /* 
-     * Both user and path may be null indicating that the default should be
-     * used. Strictly, the default for path isn't fixed so it needs to be
-     * calculated. The default for user is a constant so use that directly.
-     */
-    if (!szPath) {
-        if (GetSystemDirectoryW(sPath, MAX_PATH) == 0) {
-            lstrlcpyW(sPath, MAX_PATH, L"%windir%\\system32");
-        }
-        lstrlcatW(sPath, MAX_PATH, LOG_PATH_DEFAULT);
-    }
-    else {
-        lstrlcpyW(sPath, MAX_PATH, szPath);
-    }
-
-    errmsg[0] = '\0';
-    if (dwError != ERROR_SUCCESS) {
-        len = apxGetMessage(dwError, errmsg, SIZ_DESLEN);
-        errmsg[len] = '\0';
-        if (len > 0) {
-            if (errmsg[len - 1] == '\n')
-                errmsg[--len] = '\0';
-            if (len > 0 && errmsg[len - 1] == '\r')
-                errmsg[--len] = '\0';
-        }
-    }
-
-    apxLogWrite(APXLOG_MARK_WARN "Failed to grant service user '%S' write permissions to log path '%S' due to error '%d: %s'",
-                (szUser ? szUser : DEFAULT_SERVICE_USER), sPath, dwError, errmsg);
-}
-
 /* Operations */
 static BOOL docmdInstallService(LPAPXCMDLINE lpCmdline)
 {
@@ -870,7 +832,8 @@ static BOOL docmdInstallService(LPAPXCMDLINE lpCmdline)
         apxServiceSetNames(hService, NULL, NULL, sd, su, sp);
         dwResult = apxSecurityGrantFileAccessToUser(SO_LOGPATH, su);
         if (dwResult) {
-            logGrantFileAccessFail(su, SO_LOGPATH, dwResult);
+            apxLogWrite(APXLOG_MARK_WARN "Failed to grant service user '%S' write permissions to log path '%S' due to error '%d'",
+                        su, SO_LOGPATH, dwResult);
         }
     }
     apxCloseHandle(hService);
@@ -1061,7 +1024,8 @@ static BOOL docmdUpdateService(LPAPXCMDLINE lpCmdline)
                                        sp));
         dwResult = apxSecurityGrantFileAccessToUser(SO_LOGPATH, su);
         if (dwResult) {
-            logGrantFileAccessFail(su, SO_LOGPATH, dwResult);
+            apxLogWrite(APXLOG_MARK_WARN "Failed to grant service user '%S' write permissions to log path '%S' due to error '%d'",
+                        su, SO_LOGPATH, dwResult);
         }
         /* Update the --Startup mode */
         if (ST_STARTUP & APXCMDOPT_FOUND) {
@@ -1603,7 +1567,6 @@ void WINAPI service_ctrl_handler(DWORD dwCtrlCode)
         case SERVICE_CONTROL_SHUTDOWN:
             apxLogWrite(APXLOG_MARK_INFO "Service SHUTDOWN signalled.");
         case SERVICE_CONTROL_STOP:
-            apxLogWrite(APXLOG_MARK_INFO "Service SERVICE_CONTROL_STOP signalled.");
             if (SO_STOPTIMEOUT > 0) {
                 reportServiceStatus(SERVICE_STOP_PENDING, NO_ERROR, SO_STOPTIMEOUT * 1000);
             }
@@ -1618,7 +1581,6 @@ void WINAPI service_ctrl_handler(DWORD dwCtrlCode)
             CloseHandle(stopThread);
             return;
         case SERVICE_CONTROL_INTERROGATE:
-            apxLogWrite(APXLOG_MARK_INFO "Service SERVICE_CONTROL_INTERROGATE signalled.");
             reportServiceStatusE(APXLOG_LEVEL_TRACE,
                                 _service_status.dwCurrentState,
                                 _service_status.dwWin32ExitCode,
@@ -1987,18 +1949,12 @@ void __cdecl main(int argc, char **argv)
         }
     }
 
-    /* Only configure logging to a file when running as a service */
-    if (lpCmdline->dwCmdIndex == 2) {
-        apxLogOpen(gPool, SO_LOGPATH, SO_LOGPREFIX, SO_LOGROTATE);
-        apxLogLevelSetW(NULL, SO_LOGLEVEL);
-        apxLogWrite(APXLOG_MARK_DEBUG "Apache Commons Daemon procrun log initialized.");
-        if (SO_LOGROTATE) {
-            apxLogWrite(APXLOG_MARK_DEBUG "Log will rotate each %d seconds.", SO_LOGROTATE);
-        }
-    } else {
-        /* Not running as a service, just set the log level */
-        apxLogLevelSetW(NULL, SO_LOGLEVEL);
-    }
+    apxLogOpen(gPool, SO_LOGPATH, SO_LOGPREFIX, SO_LOGROTATE);
+    apxLogLevelSetW(NULL, SO_LOGLEVEL);
+    apxLogWrite(APXLOG_MARK_DEBUG "Apache Commons Daemon procrun log initialized.");
+    if (SO_LOGROTATE)
+        apxLogWrite(APXLOG_MARK_DEBUG "Log will rotate each %d seconds.", SO_LOGROTATE);
+
     apxLogWrite(APXLOG_MARK_INFO "Apache Commons Daemon procrun (%s %d-bit) started.",
                 PRG_VERSION, PRG_BITS);
 
